@@ -1,6 +1,6 @@
 package Getopt::EX::Hashed;
 
-our $VERSION = '1.0502';
+our $VERSION = '1.0503';
 
 =head1 NAME
 
@@ -8,7 +8,7 @@ Getopt::EX::Hashed - Hash store object automation for Getopt::Long
 
 =head1 VERSION
 
-Version 1.0502
+Version 1.0503
 
 =head1 SYNOPSIS
 
@@ -155,13 +155,15 @@ sub new {
     for my $m (@$master) {
 	my($name, %param) = @$m;
 	push @$member, [ $name => \%param ];
+	next if $name eq '<>';
 	if (my $is = $param{is}) {
 	    no strict 'refs';
 	    my $sub = "$class\::" . $config->{ACCESSOR_PREFIX} . $name;
-	    if (not defined &$sub) {
-		$is = 'lv' if $is eq 'rw' && $config->{ACCESSOR_LVALUE};
-		*$sub = _accessor($is, $name);
+	    if (defined &$sub) {
+		croak "&$sub already exists.\n";
 	    }
+	    $is = 'lv' if $is eq 'rw' && $config->{ACCESSOR_LVALUE};
+	    *$sub = _accessor($is, $name);
 	}
 	$obj->{$name} = do {
 	    local $_ = $param{default};
@@ -175,6 +177,18 @@ sub new {
     $obj;
 }
 
+sub DESTROY {
+    my $obj = shift;
+    my $pkg = ref $obj;
+    my $hash = do { no strict 'refs'; \%{"$pkg\::"} };
+    my $prefix = $obj->_conf->{ACCESSOR_PREFIX};
+    for (@{ $obj->_member }) {
+	next unless $_->[1]->{is};
+	my $name = $prefix . $_->[0];
+	delete $hash->{$name} if exists $hash->{$name};
+    }
+}
+
 sub optspec {
     my $obj = shift;
     map $obj->_opt_pair($_), @{$obj->_member};
@@ -359,16 +373,17 @@ __END__
 
 B<Getopt::EX::Hashed> is a module to automate a hash object to store
 command line option values for B<Getopt::Long> and compatible modules
-including B<Getopt::EX::Long>.
+including B<Getopt::EX::Long>.  Module name shares B<Getopt::EX>, but
+it works independently from other modules in B<Getopt::EX>, so far.
 
 Major objective of this module is integrating initialization and
-specification into single place.
+specification into single place.  It also provides simple validation
+interface.
 
-Module name shares B<Getopt::EX>, but it works independently from
-other modules in B<Getopt::EX>, so far.
-
-Accessor methods are automatically generated when appropriate parameter
-is given.
+Accessor methods are automatically generated when C<is> parameter is
+given.  If the same function is already defined, the program causes
+fatal error.  Accessors are removed when the object is destroyed.
+Problems may occur when multiple objects are present at the same time.
 
 =head1 FUNCTION
 
